# Man recap

> recap  [subject-name] - In shell mode, it prints out a conversation. If no name are given it will print the current conversation. If one argument is given, it will try to print out a conversation under that subject name.

## Usage

`recap`

`recap historyOfHumanity`